
# bedrock-rnd - curated footprints, symbols and devmaps for Ringdove EDA
# Copyright (C) 2025  Tibor 'Igor2' Palinkas
#
# dist-license: GPL2+
# use-license (license of the output): unlimited (CC0 or public domain)
#
# For more information: doc/license.html
#        or on the web: http://www.repo.hu/projects/bedrock-rnd/license.html
#
# Project page: http://www.repo.hu/projects/bedrock-rnd
#

BEGIN {
	gversion="2025-01-20"
	generator = "pas2-rfp"
	bedrock_ver = "2025-01-10a"
}

BEGIN {
	help_auto()

	proc_args(P, "PO,PRP,PL,PW,PG,CYE,PT" ipc_params, "PL,PW")

# load args
	load_dim(P["PW"],  "PW")
	load_dim(P["PL"],  "PL")
	load_dim(P["PO"],  "PO")


	load_dim(P["PRP"], "PRP")
	load_dim(P["PG"],  "PG")
	load_dim(P["CYE"], "CYE")
	load_dim(P["PT"],  "PT")
	load_dim(P["PE"],  "PE")

	ipc_init_gentol()

# improvise missing component drawing data
	if (P["CYE"] == "")
		load_rfp("CYE", mm(0.25))

	if (P["PRP"] == "") {
		if (P["PO"] != "")
			P["PRP"] = NOM["PO"] - NOM["PL"]
		else if (P["PG"] != "")
			P["PRP"] = NOM["PG"] + NOM["PL"]
		else
			error("Need one of PRP, PO or PG")
		load_rfp("PRP", P["PRP"])
	}

	if (P["PE"] == "")
		load_rfp("PE", (NOM["PRP"] + NOM["PL"]) * 0.8)
	if (P["PG"] == "")
		load_rfp("PG", NOM["PRP"] - NOM["PL"]*0.9)

	if (P["PT"] == "")
		load_rfp("PT", NOM["PW"] * 0.8)

# compute pad geo
	pad_geo_rect_square(PADGEO, P["density"], NOM["PE"])

	# set up and call draw function
	D["pad_spacing"] = NOM["PRP"]
	D["pad_length"] = NOM["PL"]
	D["pad_width"] = NOM["PW"]

	D["lead_width"] = NOM["PT"]
	D["lead_extent"] = NOM["PE"]
	D["lead_gap"] = NOM["PG"]
	D["courtyard_extent"] = PADGEO["cy"]

	rp_pas_draw(D)
}
