
# bedrock-rnd - curated footprints, symbols and devmaps for Ringdove EDA
# Copyright (C) 2025  Tibor 'Igor2' Palinkas
#
# dist-license: GPL2+
# use-license (license of the output): unlimited (CC0 or public domain)
#
# For more information: doc/license.html
#        or on the web: http://www.repo.hu/projects/bedrock-rnd/license.html
#
# Project page: http://www.repo.hu/projects/bedrock-rnd
#

BEGIN {
	gversion="2025-01-20"
	generator = "plcc-ipc"
	bedrock_ver = "2025-01-08a"
}

BEGIN {
	help_auto()

	proc_args(P, "density,N,NL,NW,BS,BL,BW,PE,PEL,PEW,PP,PT,PC,PG,ECPL,ECPW" ipc_params centerpad_params, "density,PP,PT")

	square_vs_rectangle_body()

# load args
	load_dim(P["BL"],  "BL")
	load_dim(P["BW"],  "BW")
	load_dim(P["PP"],  "PP")
	load_dim(P["PE"],  "PE")
	load_dim(P["PT"],  "PT")
	load_dim(P["PC"],  "PC")
	load_dim(P["PG"],  "PG")
	load_dim(P["ECPL"],  "ECPL")
	load_dim(P["ECPW"],  "ECPW")
	ipc_init_gentol()

	if ((P["PC"] == "") && (P["PG"] == "")) {
		print "Either (PC) or (PGL and PGW) needs to be specified" > "/dev/stderr"
		exit 1
	}
	else if (P["PGL"] == "") {
		MAX["PGL"] = MAX["PEL"] - 2*MIN["PC"]
		MIN["PGL"] = MIN["PEL"] - 2*MAX["PC"]
		mktol("PGL")
		MAX["PGW"] = MAX["PEW"] - 2*MIN["PC"]
		MIN["PGW"] = MIN["PEW"] - 2*MAX["PC"]
		mktol("PGW")
	}
	else if (P["PC"] == "") {
		MAX["PC"] = (MAX[PEL] - MIN["PGL"]) / 2
		MIN["PC"] = (MIN[PEL] - MAX["PGL"]) / 2
		mktol("PC")
	}

# compute pad geo
	pad_geo_J_leads(PADGEO, P["density"])
	ZmaxL = ipc_calc_extent(PADGEO, "PEL")
	GminL = ipc_calc_gap(PADGEO, "PEL", "PGL")
	Xmax = ipc_calc_pin_thick(PADGEO, "PT")

	ZmaxW = ipc_calc_extent(PADGEO, "PEW")
	GminW = ipc_calc_gap(PADGEO, "PEW", "PGW")

#print "Zmax=" Zmax, "Gmin=" Gmin > "/dev/stderr"

	# set up and call draw function
	D["pitch"] = NOM["PP"]
	D["pad_spacing_length"] = (ZmaxL+GminL)/2
	D["pad_spacing_width"] = (ZmaxW+GminW)/2
	D["pad_length"] = (ZmaxL-GminL)/2
	D["pad_width"] = Xmax

	D["lead_width"] = NOM["PT"]
	D["lead_width_max"] = MAX["PT"]
	D["lead_extent_length"] = NOM["PEL"]
	D["lead_extent_width"] = NOM["PEW"]
	D["lead_gap_width"] = NOM["PGW"]
	D["lead_gap_length"] = NOM["PGL"]
	D["body_width"] = NOM["BW"]
	D["body_width_max"] = MAX["BW"]
	D["body_length"] = NOM["BL"]
	D["body_length_max"] = MAX["BL"]
	D["courtyard_extent"] = PADGEO["cy"]
	D["cpad_length"] = NOM["ECPL"]
	D["cpad_width"] = NOM["ECPW"]

	D["pin1_top"] = 1

	centerpad_setup(D, P)

	gullwing4_draw(D, "J")
}
